@@ -2,7 +2,7 @@
  *
  *  oFono - Open Source Telephony
  *
- *  Copyright (C) 2008-2009  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2008-2010  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -60,7 +60,6 @@ static void at_crsm_info_cb(gboolean ok, GAtResult *result, gpointer user_data)
 	int str;
 	unsigned char access[3];
 
-	dump_response("at_crsm_info_cb", ok, result);
 	decode_at_error(&error, g_at_result_final_response(result));
 
 	if (!ok) {
@@ -81,7 +80,7 @@ static void at_crsm_info_cb(gboolean ok, GAtResult *result, gpointer user_data)
 			(sw1 == 0x90 && sw2 != 0x00))
 		goto error;
 
-	ofono_debug("crsm_info_cb: %02x, %02x, %i", sw1, sw2, len);
+	DBG("crsm_info_cb: %02x, %02x, %i", sw1, sw2, len);
 
 	if (response[0] == 0x62)
 		ok = sim_parse_3g_get_response(response, len, &flen, &rlen,
@@ -137,7 +136,6 @@ static void at_crsm_read_cb(gboolean ok, GAtResult *result,
 	const guint8 *response;
 	gint sw1, sw2, len;
 
-	dump_response("at_crsm_read_cb", ok, result);
 	decode_at_error(&error, g_at_result_final_response(result));
 
 	if (!ok) {
@@ -162,7 +160,7 @@ static void at_crsm_read_cb(gboolean ok, GAtResult *result,
 		return;
 	}
 
-	ofono_debug("crsm_read_cb: %02x, %02x, %d", sw1, sw2, len);
+	DBG("crsm_read_cb: %02x, %02x, %d", sw1, sw2, len);
 
 	cb(&error, response, len, cbd->data);
 }
@@ -226,7 +224,6 @@ static void at_crsm_update_cb(gboolean ok, GAtResult *result,
 	struct ofono_error error;
 	gint sw1, sw2;
 
-	dump_response("at_crsm_update_cb", ok, result);
 	decode_at_error(&error, g_at_result_final_response(result));
 
 	if (!ok) {
@@ -250,7 +247,7 @@ static void at_crsm_update_cb(gboolean ok, GAtResult *result,
 		return;
 	}
 
-	ofono_debug("crsm_update_cb: %02x, %02x", sw1, sw2);
+	DBG("crsm_update_cb: %02x, %02x", sw1, sw2);
 
 	cb(&error, cbd->data);
 }
@@ -364,7 +361,6 @@ static void at_cimi_cb(gboolean ok, GAtResult *result, gpointer user_data)
 	const char *imsi;
 	int i;
 
-	dump_response("at_cimi_cb", ok, result);
 	decode_at_error(&error, g_at_result_final_response(result));
 
 	if (!ok) {
@@ -379,7 +375,7 @@ static void at_cimi_cb(gboolean ok, GAtResult *result, gpointer user_data)
 
 	imsi = g_at_result_iter_raw_line(&iter);
 
-	ofono_debug("cimi_cb: %s", imsi);
+	DBG("cimi_cb: %s", imsi);
 
 	cb(&error, imsi, cbd->data);
 }
@@ -429,6 +425,7 @@ static struct {
 static void at_cpin_cb(gboolean ok, GAtResult *result, gpointer user_data)
 {
 	struct cb_data *cbd = user_data;
+	struct sim_data *sd = ofono_sim_get_data(cbd->user);
 	GAtResultIter iter;
 	ofono_sim_passwd_cb_t cb = cbd->cb;
 	struct ofono_error error;
@@ -436,24 +433,32 @@ static void at_cpin_cb(gboolean ok, GAtResult *result, gpointer user_data)
 	int pin_type = OFONO_SIM_PASSWORD_INVALID;
 	int i;
 	int len = sizeof(at_sim_name) / sizeof(*at_sim_name);
+	const char *final = g_at_result_final_response(result);
 
-	dump_response("at_cpin_cb", ok, result);
-	decode_at_error(&error, g_at_result_final_response(result));
+	if (sd->vendor == OFONO_VENDOR_WAVECOM && ok && strlen(final) > 7)
+		decode_at_error(&error, "OK");
+	else
+		decode_at_error(&error, final);
 
 	if (!ok) {
 		cb(&error, -1, cbd->data);
 		return;
 	}
 
-	g_at_result_iter_init(&iter, result);
+	if (sd->vendor == OFONO_VENDOR_WAVECOM) {
+		/* +CPIN: <pin> */
+		pin_required = final + 7;
+	} else {
+		g_at_result_iter_init(&iter, result);
 
-	if (!g_at_result_iter_next(&iter, "+CPIN:")) {
-		CALLBACK_WITH_FAILURE(cb, -1, cbd->data);
-		return;
+		if (!g_at_result_iter_next(&iter, "+CPIN:")) {
+			CALLBACK_WITH_FAILURE(cb, -1, cbd->data);
+			return;
+		}
+
+		g_at_result_iter_next_unquoted_string(&iter, &pin_required);
 	}
 
-	g_at_result_iter_next_unquoted_string(&iter, &pin_required);
-
 	for (i = 0; i < len; i++) {
 		if (strcmp(pin_required, at_sim_name[i].name))
 			continue;
@@ -467,7 +472,7 @@ static void at_cpin_cb(gboolean ok, GAtResult *result, gpointer user_data)
 		return;
 	}
 
-	ofono_debug("crsm_pin_cb: %s", pin_required);
+	DBG("crsm_pin_cb: %s", pin_required);
 
 	cb(&error, pin_type, cbd->data);
 }
@@ -481,6 +486,8 @@ static void at_pin_query(struct ofono_sim *sim, ofono_sim_passwd_cb_t cb,
 	if (!cbd)
 		goto error;
 
+	cbd->user = sim;
+
 	if (g_at_chat_send(sd->chat, "AT+CPIN?", NULL,
 				at_cpin_cb, cbd, g_free) > 0)
 		return;
@@ -499,7 +506,6 @@ static void at_lock_unlock_cb(gboolean ok, GAtResult *result,
 	ofono_sim_lock_unlock_cb_t cb = cbd->cb;
 	struct ofono_error error;
 
-	dump_response("at_lock_unlock_cb", ok, result);
 	decode_at_error(&error, g_at_result_final_response(result));
 
 	cb(&error, cbd->data);
@@ -653,7 +659,6 @@ static void at_lock_status_cb(gboolean ok, GAtResult *result,
 	struct ofono_error error;
 	int locked;
 
-	dump_response("at_lock_status_cb", ok, result);
 	decode_at_error(&error, g_at_result_final_response(result));
 
 	if (!ok) {
@@ -670,7 +675,7 @@ static void at_lock_status_cb(gboolean ok, GAtResult *result,
 
 	g_at_result_iter_next_number(&iter, &locked);
 
-	ofono_debug("lock_status_cb: %i", locked);
+	DBG("lock_status_cb: %i", locked);
 
 	cb(&error, locked, cbd->data);
 }
@@ -714,7 +719,6 @@ static void at_csim_envelope_cb(gboolean ok, GAtResult *result,
 	const guint8 *response;
 	gint rlen, len;
 
-	dump_response("at_csim_envelope_cb", ok, result);
 	decode_at_error(&error, g_at_result_final_response(result));
 
 	if (!ok)
@@ -735,7 +739,7 @@ static void at_csim_envelope_cb(gboolean ok, GAtResult *result,
 			response[len - 2] != 0x90 || response[len - 1] != 0)
 		goto error;
 
-	ofono_debug("csim_envelope_cb: %i", len);
+	DBG("csim_envelope_cb: %i", len);
 
 	cb(&error, response, len - 2, cbd->data);
 	return;
@@ -800,6 +804,9 @@ static int at_sim_probe(struct ofono_sim *sim, unsigned int vendor,
 	sd->chat = chat;
 	sd->vendor = vendor;
 
+	if (sd->vendor == OFONO_VENDOR_WAVECOM)
+		g_at_chat_add_terminator(chat, "+CPIN:", 6, TRUE);
+
 	ofono_sim_set_data(sim, sd);
 	g_idle_add(at_sim_register, sim);
 
